@@ -80,7 +80,8 @@ class MetaApp(object):
                  api_proxy_url: str = None,
                  include_worker: bool = None,
                  redis_url: str = None,
-                 setup_sockets: bool = True
+                 setup_sockets: bool = True,
+                 gcloud_log_host_port: str = None
                  ):
         if setup_sockets:
             self.setup_sockets()
@@ -95,15 +96,15 @@ class MetaApp(object):
         self.debug = debug
 
         defaultEnvParamList = []
-        if os.environ.get("REDIS_URL") is None:
+        if os.environ.get("REDIS_URL") is None and redis_url is None:
             defaultEnvParamList.append("REDIS_URL")
-        if os.environ.get("META_URL") is None:
+        if os.environ.get("META_URL") is None and meta_url is None:
             defaultEnvParamList.append("META_URL")
-        if os.environ.get("API_PROXY_URL") is None:
+        if os.environ.get("API_PROXY_URL") is None and api_proxy_url is None:
             defaultEnvParamList.append("API_PROXY_URL")
-        if os.environ.get("STARTER_URL") is None:
+        if os.environ.get("STARTER_URL") is None and starter_api_url is None:
             defaultEnvParamList.append("STARTER_URL")
-        if os.environ.get("GCLOUD_LOG_HOST_PORT") is None:
+        if os.environ.get("GCLOUD_LOG_HOST_PORT") is None and gcloud_log_host_port is None:
             defaultEnvParamList.append("GCLOUD_LOG_HOST_PORT")
         if len(defaultEnvParamList) > 0:
             self.log.warning("Пропущены обязательные переменные окружения: " + ", ".join(defaultEnvParamList))
@@ -119,7 +120,7 @@ class MetaApp(object):
         if service_id:
             self.log.warning("Параметр service_id скоро будет удален из MetaApp")
 
-        gcloud_log_host_port = os.environ.get("GCLOUD_LOG_HOST_PORT", "n3.adp.vmc.loc:31891")
+        gcloud_log_host_port = os.environ.get("GCLOUD_LOG_HOST_PORT", gcloud_log_host_port or "n3.adp.vmc.loc:31891")
         service_ns = os.environ.get('SERVICE_NAMESPACE', "appscript")  # для ns в логах и для префикса Dispatcher
         service_id = os.environ.get('SERVICE_ID', "local_debug_serivce")
         self.build_num = os.environ.get('BUILD_NUM', '0')
