@@ -22,8 +22,14 @@ class StarterService:
         self.log = app.log
         self.max_retries = 30
 
-    def update_task_result_data(self, task):
+    def update_task_result_data(self, task, sleep_sec=15):
         self.log.info("Сохраняем состояние в БД", {"result_data": task['result_data']})
+        if sleep_sec < 1:
+            sleep_sec = 1
+        if sleep_sec > 600:
+            sleep_sec = 600
+        max_tries = 10
+        current_try = 0
         while True:
             url = self.__starter_api_url + '/services/' + task.get('serviceId') + '/tasks/updateResultData'
             try:
@@ -40,18 +46,29 @@ class StarterService:
                 if resp.status_code == 200:
                     return
                 else:
-                    self.log.error("Ошибка при обновлении result_data задачи", {
+                    self.log.warning("Некорректный http статус при обновлении result_data задачи, пробуем снова", {
                         "task": task
                     })
-                    time.sleep(15)
-            except requests.exceptions.ConnectionError:
-                """
-                Любые сетевые ошибки пропускаем и пробуем сделать запрос снова - нам нужен корректный ответ
-                Мы точно должны записать результаты выполнения в БД
-                """
-                pass
+                    current_try = current_try + 1
+                    if current_try >= max_tries:
+                        self.log.error("Некорректный http статус при обновлении result_data задачи, прерываем выполнение", {
+                            "status_code": resp.status_code,
+                            "task": task,
+                            "response_text": resp.text
+                        })
+                        raise IOError("Starter response read error: " + resp.text)
+
             except Exception:
-                raise IOError("Starter response read error: " + resp.text)
+                self.log.warning("Неизвестная ошибка при обновлении result_data задачи, пробуем снова", {
+                    "task": task
+                })
+                current_try = current_try + 1
+                if current_try >= max_tries:
+                    self.log.error("Неизвестная ошибка при обновлении result_data задачи, прерываем выполнение", {
+                        "task": task
+                    })
+                    raise IOError("Starter response read error")
+            time.sleep(sleep_sec)
 
     def await_task(self, task_id, service_id, callback_fn=None, sleep_sec=15):
         """
@@ -73,6 +90,8 @@ class StarterService:
         if sleep_sec > 5:
             sleep_pre_sec = 5
             sleep_post_sec = sleep_sec - 5
+        max_tries = 10
+        current_try = 0
         while True:
             time.sleep(sleep_pre_sec)
             data = {"taskId": task_id}
@@ -101,13 +120,12 @@ class StarterService:
                             return serverResult
                 else:
                     return None
-            except requests.exceptions.ConnectionError:
-                """
-                Любые сетевые ошибки пропускаем и пробуем сделать запрос снова - нам нужен корректный ответ
-                """
-                pass
             except Exception:
-                raise IOError("Starter response read error: " + resp.text)
+                self.log.warning("Неизвестная ошибка при выполнении await_task, пробуем снова")
+                current_try = current_try + 1
+                if current_try >= max_tries:
+                    self.log.error("Неизвестная ошибка при выполнении await_task, прерываем выполнение")
+                    raise IOError("Starter response read error")
             time.sleep(sleep_post_sec)
 
     def submit(self, service_id: str, data: dict = None):
